
**GLASS**: Generator for Large Scale Structure
==============================================

[![Gitter](https://badges.gitter.im/glass-dev/glass.svg)](https://gitter.im/glass-dev/glass)
[![Documentation](https://readthedocs.org/projects/glass/badge/?version=latest)](https://glass.readthedocs.io/en/latest/)

This is the core library for GLASS, the Generator for Large Scale Structure.
For more information, see the full [documentation].  There are a number of
[examples] to get you started.


Installation
------------

Releases of the code can be installed with pip as usual:

    pip install glass

If you are interested in the latest version of the code, you can pip-install
this repository:

    pip install git+https://github.com/glass-dev/glass.git


Citation
--------

If you use GLASS simulations or the GLASS library in your research, please cite
the original paper.


[documentation]: https://glass.readthedocs.io/
[examples]: https://glass.readthedocs.io/projects/examples/
[glass-camb]: https://github.com/glass-dev/glass-camb/
